@@ -3,7 +3,7 @@ from django.forms import models, ValidationError
 from django.contrib import admin
 from django.contrib.contenttypes import generic
 
-from farm.models import Farm, Genus, Breed, Animal, Product, ProductType, Note, SecondaryBreed, AnimalAttribute, AnimalAttributeOption, ProductAttribute, ProductAttributeOption, Building, BuildingSpace, Field, FieldType, BuildingAttribute, FieldAttribute, BuildingAttributeOption, FieldAttributeOption
+from farm.models import Farm, Genus, Breed, Animal, Product, ProductType, Note, SecondaryBreed, AnimalAttribute, AnimalAttributeOption, ProductAttribute, ProductAttributeOption, Building, BuildingSpace, Field, FieldType, BuildingAttribute, FieldAttribute, BuildingAttributeOption, FieldAttributeOption, Milking
 from notes.admin import NoteInline
 from attributes.admin import clean_attribute_value
 
@@ -28,9 +28,13 @@ class AnimalAdmin(admin.ModelAdmin):
     list_display = ('sex', 'name', 'dam', 'birthday', 'primary_breed',)
     inlines = [ AnimalAttributeInline, SecondaryBreedInline, NoteInline, ]
 
+class MilkingAdmin(admin.ModelAdmin):
+    inlines = [ NoteInline, ]
+
 class ProductAdmin(admin.ModelAdmin):
     inlines = [ ProductAttributeInline, NoteInline, ]
 
+admin.site.register(Milking, MilkingAdmin)
 admin.site.register(Animal, AnimalAdmin)
 admin.site.register(Farm)
 admin.site.register(Genus)
